@@ -6,24 +6,23 @@
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
+from collections.abc import Callable
 from copy import copy
 from decimal import Decimal
 from io import BytesIO
 from itertools import zip_longest
 from pathlib import Path
 from shutil import copyfileobj
-from typing import Any, BinaryIO, Callable, NamedTuple, TypeVar, Union, cast
+from typing import Any, BinaryIO, NamedTuple, TypeVar, cast
 
 from PIL import Image
 from PIL.ImageCms import ImageCmsProfile
 
 from pikepdf import jbig2
-from pikepdf._core import Buffer, Pdf, StreamDecodeLevel
-from pikepdf.exceptions import (
-    DependencyError,
-    PdfError,
-)
+from pikepdf._core import Buffer, Pdf, PdfError, StreamDecodeLevel
+from pikepdf._exceptions import DependencyError
 from pikepdf.models import _transcoding
+from pikepdf.models._transcoding import ImageDecompressionError
 from pikepdf.objects import (
     Array,
     Dictionary,
@@ -38,7 +37,7 @@ T = TypeVar('T')
 RGBDecodeArray = tuple[float, float, float, float, float, float]
 GrayDecodeArray = tuple[float, float]
 CMYKDecodeArray = tuple[float, float, float, float, float, float, float, float]
-DecodeArray = Union[RGBDecodeArray, GrayDecodeArray, CMYKDecodeArray]
+DecodeArray = RGBDecodeArray | GrayDecodeArray | CMYKDecodeArray
 
 
 class UnsupportedImageTypeError(Exception):
@@ -57,18 +56,15 @@ class InvalidPdfImageError(Exception):
     """This image is not valid according to the PDF 1.7 specification."""
 
 
-ImageDecompressionError = _transcoding.ImageDecompressionError
-
-
 def _array_str(value: Object | str | list):
     """Simplify pikepdf objects to array of str. Keep streams, dictionaries intact."""
 
     def _convert(item):
-        if isinstance(item, (list, Array)):
+        if isinstance(item, list | Array):
             return [_convert(subitem) for subitem in item]
-        if isinstance(item, (Stream, Dictionary, bytes, int)):
+        if isinstance(item, Stream | Dictionary | bytes | int):
             return item
-        if isinstance(item, (Name, str)):
+        if isinstance(item, Name | str):
             return str(item)
         if isinstance(item, (String)):
             return bytes(item)
@@ -176,6 +172,8 @@ class PdfImageBase(ABC):
                 return (0.0, 1.0)
             if self._approx_mode_from_icc() == 'RGB':
                 return (0.0, 1.0, 0.0, 1.0, 0.0, 1.0)
+        if self.image_mask:
+            return (0.0, 1.0)  # Default for image masks; per RM 8.9.6.2
 
         raise NotImplementedError(
             "Don't how to retrieve default /Decode array for image" + repr(self)
@@ -967,7 +965,7 @@ class PdfInlineImage(PdfImageBase):
             return obj.unparse(resolved=True)
         if isinstance(obj, bool):
             return b'true' if obj else b'false'  # Lower case for PDF spec
-        if isinstance(obj, (int, Decimal, float)):
+        if isinstance(obj, int | Decimal | float):
             return str(obj).encode('ascii')
         raise NotImplementedError(repr(obj))
 
@@ -1052,3 +1050,19 @@ class PdfInlineImage(PdfImageBase):
         """Return decompressed stream buffer."""
         # qpdf does not have an API to return this directly, so convert it.
         return self._convert_to_pdfimage().get_stream_buffer()
+
+
+__all__ = [
+    'CMYKDecodeArray',
+    'DecodeArray',
+    'HifiPrintImageNotTranscodableError',
+    'ImageDecompressionError',
+    'InvalidPdfImageError',
+    'PaletteData',
+    'PdfImage',
+    'PdfImageBase',
+    'PdfInlineImage',
+    'PdfJpxImage',
+    'RGBDecodeArray',
+    'UnsupportedImageTypeError',
+]
